@@ -26,7 +26,7 @@ ADSSMod = function(parameters) {
   parameters$random_seed = random_seed
 
   # Set the seed of R's random number generator.
-  # It also takes effect to Rcpp randome generation functions.
+  # It also takes effect to Rcpp random generation functions.
   # https://stackoverflow.com/questions/60119621/get-the-same-sample-of-integers-from-rcpp-as-base-r
   suppressWarnings(RNGkind(sample.kind = "Rounding"))
   set.seed(random_seed)
@@ -167,7 +167,7 @@ ADSSMod = function(parameters) {
   }
 
   if (!is.null(parameters$ncores)) {
-
+    # nocov start
     # Maximum number of cores
     max_ncores = parallel::detectCores()
 
@@ -182,7 +182,7 @@ ADSSMod = function(parameters) {
                            c("Value"),
                            "int",
                            NA) 
-
+    # nocov end
   } else {
     parameters$ncores = 1
   }
@@ -433,7 +433,7 @@ ADSSMod = function(parameters) {
   # Run simulations on multiple cores to compute key characteristics
 
   if (parameters$ncores > 1) {
-
+    # nocov start
     cl = parallel::makeCluster(parameters$ncores)
 
     # Export all functions in the global environment to each node
@@ -454,7 +454,7 @@ ADSSMod = function(parameters) {
       sim_results = rbind(sim_results, simulation_list[[i]]$sim_results)
 
     }
-
+    # nocov end
   } else {
 
     simulations = ADSSModSingleCore(parameters)
@@ -515,7 +515,7 @@ ADSSModReportDoc = function(results) {
 
    # Error checks
 
-   if (class(results) != "ADSSModResults") stop("The object was not created by the ADSSMod function", call. = FALSE)
+   if (!is(results, "ADSSModResults")) stop("The object was not created by the ADSSMod function", call. = FALSE)
 
   #############################################################################
 
